@@ -1,3 +1,14 @@
+#
+#  This file is part of Biosniff software
+#
+#  Copyright (c) 2021-2022 - Biosniff Team
+#
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  Website:       https://github.com/cokelaer/biosniff
+##############################################################################
+
 import yaml
 import xml.etree.ElementTree as ET
 import json
@@ -57,11 +68,7 @@ class Sniffer(object):
             func = getattr(self, "is_{}".format(extension))
             ret = func(filename)
             if ret is True:
-                _log.debug(
-                    "Confirm the format based on extension and is_{} function".format(
-                        extension
-                    )
-                )
+                _log.debug("Confirm the format based on extension and is_{} function".format(extension))
                 candidates.append(extension)
             else:
                 raise Error
@@ -91,7 +98,7 @@ class Sniffer(object):
             return None
         elif len(candidates) == 1:
             return candidates[0]
-        else:
+        else: #pragma: no cover
             _log.warning("Sniffer found several candidates: {}".format(candidates))
 
             return candidates
@@ -130,7 +137,7 @@ class Sniffer(object):
             buff = data.read(4)
             if buff[0:4].decode() == "ABIF":
                 return True
-        except:
+        except: #pragma: no cover
             return False
 
     def is_bam(self, filename):
@@ -147,14 +154,14 @@ class Sniffer(object):
                 return True
             else:
                 return False
-        except:
+        except: #pragma: no cover
             return False
 
     def is_bcf(self, filename):
         try:
             d = pysam.VariantFile(filename)
             return d.is_bcf
-        except:
+        except: #pragma: no cover
             return False
 
     def is_binary_bed(self, filename):
